@@ -37,7 +37,8 @@ class Workflow:
         wkf.run()
         ...
   """
-  def __init__(self, context, name, packages, workspace, steps, instances=None):
+  def __init__(self, context, name, packages, workspace,
+               steps, log_level=None, instances=None):
     self.name = name.replace(" ", "_")
     self.packages = packages
     self.workspace = workspace
@@ -46,7 +47,8 @@ class Workflow:
     if instances is None:
       self.instances = list()
     self.ctx = context.reset(session=str(uuid.uuid4()),
-                             workspace_cfg=self.workspace)
+                             workspace_cfg=self.workspace,
+                             log_level=log_level)
 
   def __enter__(self):
     return self
